/* snapshots-property.c generated by valac 0.30.0.37-86f3c, the Vala compiler
 * generated from snapshots-property.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <float.h>
#include <math.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libgd/gd.h>


#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesPropertyPrivate BoxesPropertyPrivate;

#define BOXES_TYPE_SNAPSHOTS_PROPERTY (boxes_snapshots_property_get_type ())
#define BOXES_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty))
#define BOXES_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))
#define BOXES_IS_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_IS_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_SNAPSHOTS_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))

typedef struct _BoxesSnapshotsProperty BoxesSnapshotsProperty;
typedef struct _BoxesSnapshotsPropertyClass BoxesSnapshotsPropertyClass;
typedef struct _BoxesSnapshotsPropertyPrivate BoxesSnapshotsPropertyPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;

#define BOXES_TYPE_SNAPSHOT_LIST_ROW (boxes_snapshot_list_row_get_type ())
#define BOXES_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow))
#define BOXES_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))
#define BOXES_IS_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_IS_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_SNAPSHOT_LIST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))

typedef struct _BoxesSnapshotListRow BoxesSnapshotListRow;
typedef struct _BoxesSnapshotListRowClass BoxesSnapshotListRowClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesSnapshotsPropertyFetchSnapshotsData BoxesSnapshotsPropertyFetchSnapshotsData;
typedef struct _BoxesSnapshotListRowPrivate BoxesSnapshotListRowPrivate;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesSnapshotsPropertyCreateSnapshotData BoxesSnapshotsPropertyCreateSnapshotData;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

struct _BoxesProperty {
	GObject parent_instance;
	BoxesPropertyPrivate * priv;
};

struct _BoxesPropertyClass {
	GObjectClass parent_class;
};

struct _BoxesSnapshotsProperty {
	BoxesProperty parent_instance;
	BoxesSnapshotsPropertyPrivate * priv;
};

struct _BoxesSnapshotsPropertyClass {
	BoxesPropertyClass parent_class;
};

struct _BoxesSnapshotsPropertyPrivate {
	BoxesLibvirtMachine* machine;
	GtkListBox* snapshot_list;
	GtkStack* stack;
	GtkLabel* activity_label;
	GtkStack* snapshot_stack;
	GtkLabel* empty_label;
	GtkBox* activity_box;
	GtkBox* snapshot_box;
	gulong added_id;
	gulong removed_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	BoxesLibvirtMachineProperties* properties;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesSnapshotsPropertyFetchSnapshotsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSnapshotsProperty* self;
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachineProperties* _tmp1_;
	GList* snapshots;
	BoxesLibvirtMachine* _tmp2_;
	BoxesLibvirtMachineProperties* _tmp3_;
	GList* _tmp4_;
	GList* _tmp5_;
	GList* snapshot_collection;
	GList* snapshot_it;
	GVirDomainSnapshot* _tmp6_;
	GVirDomainSnapshot* snapshot;
	BoxesSnapshotListRow* row;
	GVirDomainSnapshot* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	BoxesSnapshotListRow* _tmp9_;
	BoxesSnapshotListRow* _tmp10_;
	GtkListBox* _tmp11_;
	BoxesSnapshotListRow* _tmp12_;
	GError* e;
	GError* _tmp13_;
	const gchar* _tmp14_;
	GError * _inner_error_;
};

struct _BoxesSnapshotListRow {
	GtkListBoxRow parent_instance;
	BoxesSnapshotListRowPrivate * priv;
	GVirDomainSnapshot* snapshot;
};

struct _BoxesSnapshotListRowClass {
	GtkListBoxRowClass parent_class;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesSnapshotsPropertyCreateSnapshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSnapshotsProperty* self;
	BoxesLibvirtMachine* _tmp0_;
	BoxesMachineMachineState _tmp1_;
	BoxesMachineMachineState _tmp2_;
	const gchar* _tmp3_;
	GVirDomainSnapshot* new_snapshot;
	BoxesLibvirtMachine* _tmp4_;
	GVirDomainSnapshot* _tmp5_;
	BoxesSnapshotListRow* new_row;
	BoxesLibvirtMachine* _tmp6_;
	BoxesSnapshotListRow* _tmp7_;
	BoxesSnapshotListRow* _tmp8_;
	GtkListBox* _tmp9_;
	BoxesSnapshotListRow* _tmp10_;
	GError* e;
	gchar* msg;
	const gchar* _tmp11_;
	BoxesLibvirtMachine* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	BoxesLibvirtMachine* _tmp16_;
	BoxesAppWindow* _tmp17_;
	BoxesAppWindow* _tmp18_;
	BoxesNotificationbar* _tmp19_;
	BoxesNotificationbar* _tmp20_;
	const gchar* _tmp21_;
	GdNotification* _tmp22_;
	GdNotification* _tmp23_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	GError * _inner_error_;
};


static gpointer boxes_snapshots_property_parent_class = NULL;

GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_snapshots_property_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_SNAPSHOTS_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyPrivate))
enum  {
	BOXES_SNAPSHOTS_PROPERTY_DUMMY_PROPERTY
};
BoxesSnapshotsProperty* boxes_snapshots_property_new (BoxesLibvirtMachine* machine);
BoxesSnapshotsProperty* boxes_snapshots_property_construct (GType object_type, BoxesLibvirtMachine* machine);
BoxesProperty* boxes_property_new (const gchar* description, GtkWidget* widget, GtkWidget* extra_widget);
BoxesProperty* boxes_property_construct (GType object_type, const gchar* description, GtkWidget* widget, GtkWidget* extra_widget);
static void __lambda173_ (BoxesSnapshotsProperty* self);
static void boxes_snapshots_property_create_snapshot (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_snapshots_property_create_snapshot_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_);
static void ___lambda173__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
static gint boxes_snapshots_property_config_sort_func (BoxesSnapshotsProperty* self, GtkListBoxRow* row1, GtkListBoxRow* row2);
static gint _boxes_snapshots_property_config_sort_func_gtk_list_box_sort_func (GtkListBoxRow* row1, GtkListBoxRow* row2, gpointer self);
static void boxes_snapshots_property_update_snapshot_stack_page (BoxesSnapshotsProperty* self);
static void _boxes_snapshots_property_update_snapshot_stack_page_gtk_container_add (GtkContainer* _sender, GtkWidget* widget, gpointer self);
static void _boxes_snapshots_property_update_snapshot_stack_page_gtk_container_remove (GtkContainer* _sender, GtkWidget* widget, gpointer self);
static void boxes_snapshots_property_on_flushed (BoxesSnapshotsProperty* self);
static void _boxes_snapshots_property_on_flushed_boxes_property_flushed (BoxesProperty* _sender, gpointer self);
static void boxes_snapshots_property_fetch_snapshots (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_snapshots_property_fetch_snapshots_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_);
static void boxes_snapshots_property_fetch_snapshots_data_free (gpointer _data);
static gboolean boxes_snapshots_property_fetch_snapshots_co (BoxesSnapshotsPropertyFetchSnapshotsData* _data_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_properties_fetch_snapshots (BoxesLibvirtMachineProperties* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_properties_fetch_snapshots_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error);
static void boxes_snapshots_property_fetch_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GList* boxes_libvirt_machine_properties_get_snapshots (BoxesLibvirtMachineProperties* self);
GType boxes_snapshot_list_row_get_type (void) G_GNUC_CONST;
BoxesSnapshotListRow* boxes_snapshot_list_row_new (GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
BoxesSnapshotListRow* boxes_snapshot_list_row_construct (GType object_type, GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
static void boxes_snapshots_property_row_activity_changed (BoxesSnapshotsProperty* self, GObject* source, GParamSpec* param_spec);
static void _boxes_snapshots_property_row_activity_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_snapshots_property_create_snapshot_data_free (gpointer _data);
static gboolean boxes_snapshots_property_create_snapshot_co (BoxesSnapshotsPropertyCreateSnapshotData* _data_);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void boxes_snapshots_property_set_activity (BoxesSnapshotsProperty* self, const gchar* value);
void boxes_libvirt_machine_create_snapshot (BoxesLibvirtMachine* self, const gchar* description_prefix, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirDomainSnapshot* boxes_libvirt_machine_create_snapshot_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void boxes_snapshots_property_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
const gchar* boxes_snapshot_list_row_get_activity_message (BoxesSnapshotListRow* self);
static void boxes_snapshots_property_finalize (GObject* obj);
static void _vala_boxes_snapshots_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static gpointer _g_object_ref0 (gpointer self) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return self ? g_object_ref (self) : NULL;
#line 440 "snapshots-property.c"
}


static void __lambda173_ (BoxesSnapshotsProperty* self) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_create_snapshot (self, NULL, NULL);
#line 447 "snapshots-property.c"
}


static void ___lambda173__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	__lambda173_ ((BoxesSnapshotsProperty*) self);
#line 454 "snapshots-property.c"
}


static gint _boxes_snapshots_property_config_sort_func_gtk_list_box_sort_func (GtkListBoxRow* row1, GtkListBoxRow* row2, gpointer self) {
	gint result;
	result = boxes_snapshots_property_config_sort_func ((BoxesSnapshotsProperty*) self, row1, row2);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return result;
#line 463 "snapshots-property.c"
}


static void _boxes_snapshots_property_update_snapshot_stack_page_gtk_container_add (GtkContainer* _sender, GtkWidget* widget, gpointer self) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_update_snapshot_stack_page ((BoxesSnapshotsProperty*) self);
#line 470 "snapshots-property.c"
}


static void _boxes_snapshots_property_update_snapshot_stack_page_gtk_container_remove (GtkContainer* _sender, GtkWidget* widget, gpointer self) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_update_snapshot_stack_page ((BoxesSnapshotsProperty*) self);
#line 477 "snapshots-property.c"
}


static void _boxes_snapshots_property_on_flushed_boxes_property_flushed (BoxesProperty* _sender, gpointer self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_on_flushed ((BoxesSnapshotsProperty*) self);
#line 484 "snapshots-property.c"
}


BoxesSnapshotsProperty* boxes_snapshots_property_construct (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesSnapshotsProperty * self = NULL;
	GtkStack* stack = NULL;
	GtkStack* _tmp0_ = NULL;
	GtkStack* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	GtkBox* _tmp4_ = NULL;
	GtkBox* _tmp5_ = NULL;
	GtkToolbar* toolbar = NULL;
	GtkToolbar* _tmp6_ = NULL;
	GtkStyleContext* _tmp7_ = NULL;
	GtkToolButton* create_snapshot_button = NULL;
	GtkToolButton* _tmp8_ = NULL;
	GtkImage* icon_img = NULL;
	GtkImage* _tmp9_ = NULL;
	GtkStack* _tmp10_ = NULL;
	GtkStack* _tmp11_ = NULL;
	GtkListBox* _tmp12_ = NULL;
	GtkListBox* _tmp13_ = NULL;
	GtkListBox* _tmp14_ = NULL;
	GtkListBox* _tmp15_ = NULL;
	gulong _tmp16_ = 0UL;
	GtkListBox* _tmp17_ = NULL;
	gulong _tmp18_ = 0UL;
	GtkStack* _tmp19_ = NULL;
	GtkListBox* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	GtkLabel* _tmp22_ = NULL;
	GtkLabel* _tmp23_ = NULL;
	GtkLabel* _tmp24_ = NULL;
	GtkLabel* _tmp25_ = NULL;
	GtkStack* _tmp26_ = NULL;
	GtkLabel* _tmp27_ = NULL;
	GtkFrame* snapshot_list_frame = NULL;
	GtkFrame* _tmp28_ = NULL;
	GtkStack* _tmp29_ = NULL;
	GtkBox* _tmp30_ = NULL;
	GtkBox* _tmp31_ = NULL;
	GtkBox* _tmp32_ = NULL;
	GtkBox* _tmp33_ = NULL;
	GtkBox* _tmp34_ = NULL;
	GtkSpinner* activity_spinner = NULL;
	GtkSpinner* _tmp35_ = NULL;
	GtkBox* _tmp36_ = NULL;
	GtkLabel* _tmp37_ = NULL;
	GtkStyleContext* _tmp38_ = NULL;
	GtkBox* _tmp39_ = NULL;
	GtkLabel* _tmp40_ = NULL;
	GtkBox* _tmp41_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = (GtkStack*) gtk_stack_new ();
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp0_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	stack = _tmp0_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_stack_set_transition_type (stack, GTK_STACK_TRANSITION_TYPE_CROSSFADE);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self = (BoxesSnapshotsProperty*) boxes_property_construct (object_type, NULL, (GtkWidget*) stack, NULL);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp1_ = _g_object_ref0 (stack);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->stack);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->stack = _tmp1_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp2_ = machine;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->machine);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->machine = _tmp3_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp4_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp4_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_box);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->snapshot_box = _tmp4_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp5_ = self->priv->snapshot_box;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_set ((GtkWidget*) _tmp5_, "margin", 20, NULL);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp6_ = (GtkToolbar*) gtk_toolbar_new ();
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp6_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	toolbar = _tmp6_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp7_ = gtk_widget_get_style_context ((GtkWidget*) toolbar);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_style_context_add_class (_tmp7_, GTK_STYLE_CLASS_INLINE_TOOLBAR);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_toolbar_set_icon_size (toolbar, GTK_ICON_SIZE_MENU);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_valign ((GtkWidget*) toolbar, GTK_ALIGN_START);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp8_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp8_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	create_snapshot_button = _tmp8_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_signal_connect_object (create_snapshot_button, "clicked", (GCallback) ___lambda173__gtk_tool_button_clicked, self, 0);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp9_ = (GtkImage*) gtk_image_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_MENU);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp9_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	icon_img = _tmp9_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_tool_button_set_icon_widget (create_snapshot_button, (GtkWidget*) icon_img);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) toolbar, (GtkWidget*) create_snapshot_button);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp10_ = (GtkStack*) gtk_stack_new ();
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp10_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_stack);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->snapshot_stack = _tmp10_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp11_ = self->priv->snapshot_stack;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_stack_set_transition_type (_tmp11_, GTK_STACK_TRANSITION_TYPE_CROSSFADE);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp12_ = self->priv->snapshot_list;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_list_box_set_selection_mode (_tmp12_, GTK_SELECTION_NONE);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp13_ = self->priv->snapshot_list;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp13_, -1, 250);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp14_ = self->priv->snapshot_list;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_list_box_set_sort_func (_tmp14_, _boxes_snapshots_property_config_sort_func_gtk_list_box_sort_func, g_object_ref (self), g_object_unref);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp15_ = self->priv->snapshot_list;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp16_ = g_signal_connect_object ((GtkContainer*) _tmp15_, "add", (GCallback) _boxes_snapshots_property_update_snapshot_stack_page_gtk_container_add, self, 0);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->added_id = _tmp16_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp17_ = self->priv->snapshot_list;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp18_ = g_signal_connect_object ((GtkContainer*) _tmp17_, "remove", (GCallback) _boxes_snapshots_property_update_snapshot_stack_page_gtk_container_remove, self, 0);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->removed_id = _tmp18_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp19_ = self->priv->snapshot_stack;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp20_ = self->priv->snapshot_list;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) _tmp19_, (GtkWidget*) _tmp20_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp21_ = _ ("No snapshots created yet. Create one using the button below.");
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp22_ = (GtkLabel*) gtk_label_new (_tmp21_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp22_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->empty_label);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->empty_label = _tmp22_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp23_ = self->priv->empty_label;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_set ((GtkWidget*) _tmp23_, "expand", TRUE, NULL);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp24_ = self->priv->empty_label;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp24_, GTK_ALIGN_CENTER);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp25_ = self->priv->empty_label;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp25_, GTK_ALIGN_CENTER);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp26_ = self->priv->snapshot_stack;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp27_ = self->priv->empty_label;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) _tmp26_, (GtkWidget*) _tmp27_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp28_ = (GtkFrame*) gtk_frame_new (NULL);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp28_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	snapshot_list_frame = _tmp28_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp29_ = self->priv->snapshot_stack;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) snapshot_list_frame, (GtkWidget*) _tmp29_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp30_ = self->priv->snapshot_box;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp30_, (GtkWidget*) snapshot_list_frame, TRUE, TRUE, (guint) 0);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp31_ = self->priv->snapshot_box;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp31_, (GtkWidget*) toolbar, TRUE, TRUE, (guint) 0);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp32_ = self->priv->snapshot_box;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) stack, (GtkWidget*) _tmp32_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp33_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp33_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->activity_box);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->activity_box = _tmp33_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp34_ = self->priv->activity_box;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp34_, GTK_ALIGN_CENTER);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp35_ = (GtkSpinner*) gtk_spinner_new ();
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp35_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	activity_spinner = _tmp35_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_size_request ((GtkWidget*) activity_spinner, 64, 64);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_spinner_start (activity_spinner);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp36_ = self->priv->activity_box;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp36_, (GtkWidget*) activity_spinner, FALSE, FALSE, (guint) 0);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp37_ = self->priv->activity_label;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp38_ = gtk_widget_get_style_context ((GtkWidget*) _tmp37_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_style_context_add_class (_tmp38_, GTK_STYLE_CLASS_DIM_LABEL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp39_ = self->priv->activity_box;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp40_ = self->priv->activity_label;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp39_, (GtkWidget*) _tmp40_, FALSE, FALSE, (guint) 0);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp41_ = self->priv->activity_box;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) stack, (GtkWidget*) _tmp41_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_signal_connect_object ((BoxesProperty*) self, "flushed", (GCallback) _boxes_snapshots_property_on_flushed_boxes_property_flushed, self, 0);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_fetch_snapshots (self, NULL, NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (activity_spinner);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (snapshot_list_frame);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (icon_img);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (create_snapshot_button);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (toolbar);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (stack);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return self;
#line 760 "snapshots-property.c"
}


BoxesSnapshotsProperty* boxes_snapshots_property_new (BoxesLibvirtMachine* machine) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return boxes_snapshots_property_construct (BOXES_TYPE_SNAPSHOTS_PROPERTY, machine);
#line 767 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots_data_free (gpointer _data) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
	_data_ = _data;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (_data_->self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_slice_free (BoxesSnapshotsPropertyFetchSnapshotsData, _data_);
#line 778 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
	BoxesSnapshotsProperty* _tmp0_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_slice_new0 (BoxesSnapshotsPropertyFetchSnapshotsData);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_snapshots_property_fetch_snapshots);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_snapshots_property_fetch_snapshots_data_free);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->self = _tmp0_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_fetch_snapshots_co (_data_);
#line 797 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 805 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = _user_data_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_source_object_ = source_object;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_res_ = _res_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_fetch_snapshots_co (_data_);
#line 819 "snapshots-property.c"
}


static void _boxes_snapshots_property_row_activity_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_row_activity_changed ((BoxesSnapshotsProperty*) self, _sender, pspec);
#line 826 "snapshots-property.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 833 "snapshots-property.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_list_free (self);
#line 842 "snapshots-property.c"
}


static gboolean boxes_snapshots_property_fetch_snapshots_co (BoxesSnapshotsPropertyFetchSnapshotsData* _data_) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	switch (_data_->_state_) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 0:
#line 851 "snapshots-property.c"
		goto _state_0;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 1:
#line 855 "snapshots-property.c"
		goto _state_1;
		default:
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_assert_not_reached ();
#line 860 "snapshots-property.c"
	}
	_state_0:
	{
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp0_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp0_ = _data_->self->priv->machine;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp1_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp1_ = _data_->_tmp0_->properties;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_state_ = 1;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_libvirt_machine_properties_fetch_snapshots (_data_->_tmp1_, NULL, boxes_snapshots_property_fetch_snapshots_ready, _data_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 878 "snapshots-property.c"
		_state_1:
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_libvirt_machine_properties_fetch_snapshots_finish (_data_->_tmp1_, _data_->_res_, &_data_->_inner_error_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 884 "snapshots-property.c"
			goto __catch147_g_error;
		}
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp2_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp2_ = _data_->self->priv->machine;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = _data_->_tmp2_->properties;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = boxes_libvirt_machine_properties_get_snapshots (_data_->_tmp3_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->snapshots = _data_->_tmp4_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = _data_->snapshots;
#line 905 "snapshots-property.c"
		{
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_data_->snapshot_collection = _data_->_tmp5_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			for (_data_->snapshot_it = _data_->snapshot_collection; _data_->snapshot_it != NULL; _data_->snapshot_it = _data_->snapshot_it->next) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
				_data_->_tmp6_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
				_data_->_tmp6_ = _g_object_ref0 ((GVirDomainSnapshot*) _data_->snapshot_it->data);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
				_data_->snapshot = _data_->_tmp6_;
#line 917 "snapshots-property.c"
				{
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp7_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp7_ = _data_->snapshot;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp8_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp8_ = _data_->self->priv->machine;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp9_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp9_ = boxes_snapshot_list_row_new (_data_->_tmp7_, _data_->_tmp8_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					g_object_ref_sink (_data_->_tmp9_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->row = _data_->_tmp9_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp10_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp10_ = _data_->row;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					g_signal_connect_object ((GObject*) _data_->_tmp10_, "notify::activity-message", (GCallback) _boxes_snapshots_property_row_activity_changed_g_object_notify, _data_->self, 0);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp11_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp11_ = _data_->self->priv->snapshot_list;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp12_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp12_ = _data_->row;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					gtk_container_add ((GtkContainer*) _data_->_tmp11_, (GtkWidget*) _data_->_tmp12_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_g_object_unref0 (_data_->row);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_g_object_unref0 (_data_->snapshot);
#line 955 "snapshots-property.c"
				}
			}
		}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 961 "snapshots-property.c"
	}
	goto __finally147;
	__catch147_g_error:
	{
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->e = _data_->_inner_error_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_inner_error_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = _data_->e;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = _data_->_tmp13_->message;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_warning ("snapshots-property.vala:100: Could not fetch snapshots: %s", _data_->_tmp14_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_error_free0 (_data_->e);
#line 982 "snapshots-property.c"
	}
	__finally147:
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_clear_error (&_data_->_inner_error_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 993 "snapshots-property.c"
	}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_update_snapshot_stack_page (_data_->self);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_data_->_state_ == 0) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1001 "snapshots-property.c"
	} else {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1005 "snapshots-property.c"
	}
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_unref (_data_->_async_result);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return FALSE;
#line 1011 "snapshots-property.c"
}


static gint boxes_snapshots_property_config_sort_func (BoxesSnapshotsProperty* self, GtkListBoxRow* row1, GtkListBoxRow* row2) {
	gint result = 0;
	GError * _inner_error_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (row1 != NULL, 0);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (row2 != NULL, 0);
#line 1024 "snapshots-property.c"
	{
		GVirConfigDomainSnapshot* conf1 = NULL;
		GtkListBoxRow* _tmp0_ = NULL;
		GVirDomainSnapshot* _tmp1_ = NULL;
		GVirConfigDomainSnapshot* _tmp2_ = NULL;
		GVirConfigDomainSnapshot* conf2 = NULL;
		GtkListBoxRow* _tmp3_ = NULL;
		GVirDomainSnapshot* _tmp4_ = NULL;
		GVirConfigDomainSnapshot* _tmp5_ = NULL;
		GVirConfigDomainSnapshot* _tmp6_ = NULL;
		glong _tmp7_ = 0L;
		GVirConfigDomainSnapshot* _tmp8_ = NULL;
		glong _tmp9_ = 0L;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp0_ = row1;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp1_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_SNAPSHOT_LIST_ROW) ? ((BoxesSnapshotListRow*) _tmp0_) : NULL)->snapshot;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp2_ = gvir_domain_snapshot_get_config (_tmp1_, (guint) 0, &_inner_error_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		conf1 = _tmp2_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1048 "snapshots-property.c"
			goto __catch148_g_error;
		}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp3_ = row2;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp4_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_SNAPSHOT_LIST_ROW) ? ((BoxesSnapshotListRow*) _tmp3_) : NULL)->snapshot;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp5_ = gvir_domain_snapshot_get_config (_tmp4_, (guint) 0, &_inner_error_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		conf2 = _tmp5_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf1);
#line 1063 "snapshots-property.c"
			goto __catch148_g_error;
		}
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp6_ = conf1;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp7_ = gvir_config_domain_snapshot_get_creation_time (_tmp6_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp8_ = conf2;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp9_ = gvir_config_domain_snapshot_get_creation_time (_tmp8_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (_tmp7_ < _tmp9_) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			result = -1;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf2);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf1);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			return result;
#line 1084 "snapshots-property.c"
		} else {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			result = 1;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf2);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf1);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			return result;
#line 1094 "snapshots-property.c"
		}
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (conf2);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (conf1);
#line 1100 "snapshots-property.c"
	}
	goto __finally148;
	__catch148_g_error:
	{
		GError* e = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		e = _inner_error_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_inner_error_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp10_ = e;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp11_ = _tmp10_->message;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_warning ("snapshots-property.vala:115: Failed to fetch snapshot config: %s", _tmp11_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		result = 0;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_error_free0 (e);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return result;
#line 1124 "snapshots-property.c"
	}
	__finally148:
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_clear_error (&_inner_error_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return 0;
#line 1133 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot_data_free (gpointer _data) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
	_data_ = _data;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (_data_->self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_slice_free (BoxesSnapshotsPropertyCreateSnapshotData, _data_);
#line 1144 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
	BoxesSnapshotsProperty* _tmp0_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_slice_new0 (BoxesSnapshotsPropertyCreateSnapshotData);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_snapshots_property_create_snapshot);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_snapshots_property_create_snapshot_data_free);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->self = _tmp0_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_create_snapshot_co (_data_);
#line 1163 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1171 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = _user_data_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_source_object_ = source_object;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_res_ = _res_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_create_snapshot_co (_data_);
#line 1185 "snapshots-property.c"
}


static gboolean boxes_snapshots_property_create_snapshot_co (BoxesSnapshotsPropertyCreateSnapshotData* _data_) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	switch (_data_->_state_) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 0:
#line 1194 "snapshots-property.c"
		goto _state_0;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 1:
#line 1198 "snapshots-property.c"
		goto _state_1;
		default:
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_assert_not_reached ();
#line 1203 "snapshots-property.c"
	}
	_state_0:
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp0_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp0_ = _data_->self->priv->machine;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp1_ = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp1_ = boxes_machine_get_state ((BoxesMachine*) _data_->_tmp0_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp2_ = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_data_->_tmp2_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = _ ("Creating new snapshot…");
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_snapshots_property_set_activity (_data_->self, _data_->_tmp3_);
#line 1226 "snapshots-property.c"
	}
	{
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = _data_->self->priv->machine;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_state_ = 1;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_libvirt_machine_create_snapshot (_data_->_tmp4_, "", boxes_snapshots_property_create_snapshot_ready, _data_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 1239 "snapshots-property.c"
		_state_1:
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = boxes_libvirt_machine_create_snapshot_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->new_snapshot = _data_->_tmp5_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1249 "snapshots-property.c"
			goto __catch149_g_error;
		}
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp6_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp6_ = _data_->self->priv->machine;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp7_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp7_ = boxes_snapshot_list_row_new (_data_->new_snapshot, _data_->_tmp6_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_object_ref_sink (_data_->_tmp7_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->new_row = _data_->_tmp7_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp8_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp8_ = _data_->new_row;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp8_, "notify::activity-message", (GCallback) _boxes_snapshots_property_row_activity_changed_g_object_notify, _data_->self, 0);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp9_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp9_ = _data_->self->priv->snapshot_list;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp10_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp10_ = _data_->new_row;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_container_add ((GtkContainer*) _data_->_tmp9_, (GtkWidget*) _data_->_tmp10_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (_data_->new_row);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (_data_->new_snapshot);
#line 1284 "snapshots-property.c"
	}
	goto __finally149;
	__catch149_g_error:
	{
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->e = _data_->_inner_error_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_inner_error_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp11_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp11_ = _ ("Failed to create snapshot of %s");
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp12_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp12_ = _data_->self->priv->machine;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp12_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = _data_->_tmp13_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp15_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp15_ = g_strdup_printf (_data_->_tmp11_, _data_->_tmp14_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->msg = _data_->_tmp15_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp16_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp16_ = _data_->self->priv->machine;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp17_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp17_ = boxes_machine_get_window ((BoxesMachine*) _data_->_tmp16_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp18_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp18_ = _data_->_tmp17_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp19_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp19_ = boxes_app_window_get_notificationbar (_data_->_tmp18_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp20_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp20_ = _data_->_tmp19_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp21_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp21_ = _data_->msg;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp22_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp22_ = boxes_notificationbar_display_error (_data_->_tmp20_, _data_->_tmp21_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp23_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (_data_->_tmp23_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp24_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp24_ = _data_->e;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp25_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp25_ = _data_->_tmp24_->message;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_warning ("snapshots-property.vala:132: %s", _data_->_tmp25_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_free0 (_data_->msg);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_error_free0 (_data_->e);
#line 1363 "snapshots-property.c"
	}
	__finally149:
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_clear_error (&_data_->_inner_error_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 1374 "snapshots-property.c"
	}
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_set_activity (_data_->self, NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_data_->_state_ == 0) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1382 "snapshots-property.c"
	} else {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1386 "snapshots-property.c"
	}
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_unref (_data_->_async_result);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return FALSE;
#line 1392 "snapshots-property.c"
}


static void boxes_snapshots_property_row_activity_changed (BoxesSnapshotsProperty* self, GObject* source, GParamSpec* param_spec) {
	BoxesSnapshotListRow* row = NULL;
	GObject* _tmp0_ = NULL;
	BoxesSnapshotListRow* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (self != NULL);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (source != NULL);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (param_spec != NULL);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = source;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_SNAPSHOT_LIST_ROW) ? ((BoxesSnapshotListRow*) _tmp0_) : NULL);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	row = _tmp1_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp2_ = boxes_snapshot_list_row_get_activity_message (row);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp3_ = _tmp2_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_set_activity (self, _tmp3_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (row);
#line 1422 "snapshots-property.c"
}


static void boxes_snapshots_property_update_snapshot_stack_page (BoxesSnapshotsProperty* self) {
	guint num_snapshots = 0U;
	GtkListBox* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	guint _tmp4_ = 0U;
	guint _tmp5_ = 0U;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (self != NULL);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = self->priv->snapshot_list;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp2_ = _tmp1_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp3_ = g_list_length (_tmp2_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp4_ = _tmp3_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_list_free0 (_tmp2_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	num_snapshots = _tmp4_;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp5_ = num_snapshots;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_tmp5_ > ((guint) 0)) {
#line 1454 "snapshots-property.c"
		GtkStack* _tmp6_ = NULL;
		GtkListBox* _tmp7_ = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp6_ = self->priv->snapshot_stack;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp7_ = self->priv->snapshot_list;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_stack_set_visible_child (_tmp6_, (GtkWidget*) _tmp7_);
#line 1463 "snapshots-property.c"
	} else {
		GtkStack* _tmp8_ = NULL;
		GtkLabel* _tmp9_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp8_ = self->priv->snapshot_stack;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp9_ = self->priv->empty_label;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_stack_set_visible_child (_tmp8_, (GtkWidget*) _tmp9_);
#line 1473 "snapshots-property.c"
	}
}


static void boxes_snapshots_property_on_flushed (BoxesSnapshotsProperty* self) {
	gulong _tmp0_ = 0UL;
	gulong _tmp3_ = 0UL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (self != NULL);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = self->priv->added_id;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 1487 "snapshots-property.c"
		GtkListBox* _tmp1_ = NULL;
		gulong _tmp2_ = 0UL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp1_ = self->priv->snapshot_list;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp2_ = self->priv->added_id;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		self->priv->added_id = (gulong) 0;
#line 1498 "snapshots-property.c"
	}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp3_ = self->priv->removed_id;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_tmp3_ != ((gulong) 0)) {
#line 1504 "snapshots-property.c"
		GtkListBox* _tmp4_ = NULL;
		gulong _tmp5_ = 0UL;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp4_ = self->priv->snapshot_list;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp5_ = self->priv->removed_id;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_signal_handler_disconnect ((GObject*) _tmp4_, _tmp5_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		self->priv->removed_id = (gulong) 0;
#line 1515 "snapshots-property.c"
	}
}


static void boxes_snapshots_property_set_activity (BoxesSnapshotsProperty* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (self != NULL);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = value;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_tmp0_ == NULL) {
#line 1528 "snapshots-property.c"
		GtkStack* _tmp1_ = NULL;
		GtkBox* _tmp2_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp1_ = self->priv->stack;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp2_ = self->priv->snapshot_box;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_stack_set_visible_child (_tmp1_, (GtkWidget*) _tmp2_);
#line 1537 "snapshots-property.c"
	} else {
		GtkLabel* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GtkStack* _tmp5_ = NULL;
		GtkBox* _tmp6_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp3_ = self->priv->activity_label;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp4_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_label_set_label (_tmp3_, _tmp4_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp5_ = self->priv->stack;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp6_ = self->priv->activity_box;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_stack_set_visible_child (_tmp5_, (GtkWidget*) _tmp6_);
#line 1555 "snapshots-property.c"
	}
}


static void boxes_snapshots_property_class_init (BoxesSnapshotsPropertyClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_type_class_add_private (klass, sizeof (BoxesSnapshotsPropertyPrivate));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_snapshots_property_set_property;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_snapshots_property_finalize;
#line 1569 "snapshots-property.c"
}


static void boxes_snapshots_property_instance_init (BoxesSnapshotsProperty * self) {
	GtkListBox* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv = BOXES_SNAPSHOTS_PROPERTY_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = (GtkListBox*) gtk_list_box_new ();
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp0_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->snapshot_list = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new ("");
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->activity_label = _tmp1_;
#line 1590 "snapshots-property.c"
}


static void boxes_snapshots_property_finalize (GObject* obj) {
	BoxesSnapshotsProperty * self;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_list);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->stack);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->activity_label);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_stack);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->empty_label);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->activity_box);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_box);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	G_OBJECT_CLASS (boxes_snapshots_property_parent_class)->finalize (obj);
#line 1616 "snapshots-property.c"
}


GType boxes_snapshots_property_get_type (void) {
	static volatile gsize boxes_snapshots_property_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_snapshots_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSnapshotsPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_snapshots_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSnapshotsProperty), 0, (GInstanceInitFunc) boxes_snapshots_property_instance_init, NULL };
		GType boxes_snapshots_property_type_id;
		boxes_snapshots_property_type_id = g_type_register_static (BOXES_TYPE_PROPERTY, "BoxesSnapshotsProperty", &g_define_type_info, 0);
		g_once_init_leave (&boxes_snapshots_property_type_id__volatile, boxes_snapshots_property_type_id);
	}
	return boxes_snapshots_property_type_id__volatile;
}


static void _vala_boxes_snapshots_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSnapshotsProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	switch (property_id) {
#line 1637 "snapshots-property.c"
		default:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		break;
#line 1643 "snapshots-property.c"
	}
}



